@@ -5,97 +5,97 @@
 #'
 #' @section Adjustment:
 #'
-#' In the \bold{univariate functional case}, when the adjustment option is selected,
-#' the value of \eqn{F} is optimised for the univariate functional dataset
-#' provided with \code{Data}.
+#' In the \bold{univariate functional case}, when the adjustment option is
+#' selected, the value of \eqn{F} is optimized for the univariate functional
+#' dataset provided with \code{Data}.
 #'
 #' In practice, a number \code{adjust$N_trials} of times a synthetic population
 #' (of size \code{adjust$tiral_size} with the same covariance (robustly
 #' estimated from data) and centerline as \code{fData} is simulated without
-#' outliers and each time an optimised value \eqn{F_i} is computed so that a
+#' outliers and each time an optimized value \eqn{F_i} is computed so that a
 #' given proportion (\code{adjust$TPR}) of observations is flagged as outliers.
 #' The final value of \code{F} for the functional boxplot is determined as an
-#' average of \eqn{F_1, F_2, \ldots, F_{N_{trials}}}.
-#' At each time step the optimisation problem is solved using
-#' \code{stats::uniroot} (Brent's method.
+#' average of \eqn{F_1, F_2, \dots, F_{N_{trials}}}. At each time step the
+#' optimization problem is solved using \code{stats::uniroot} (Brent's method).
 #'
-#'
-#' @param Data the univariate or multivariate functional dataset whose functional
-#' boxplot must be determined, in form of \code{fData} or \code{mfData} object.
+#' @param Data the univariate or multivariate functional dataset whose
+#'   functional boxplot must be determined, in form of \code{fData} or
+#'   \code{mfData} object.
 #' @param Depths either a vector containing the depths for each element of the
-#' dataset, or:
-#' \itemize{
-#' \item{"\emph{univariate case}"}{: a string containing the name of the method
-#' you want to use to compute it. The default is \code{'MBD'}};
-#' \item{"\emph{multivariate case}"}{: a list with elements \code{def},
-#' containing the name of the depth notion to be used to compute depths
-#' (\code{BD} or \code{MBD}), and \code{weights}, containing the value
-#' of parameter \code{weights} to be passed to the depth function. Default is
-#' \code{list( def = 'MBD', weights = 'uniform' ) }. }
-#' }
+#'   dataset, or:
+#'
+#'   * \emph{univariate case}: a string containing the name of the method you
+#'   want to use to compute it. The default is \code{'MBD'}.
+#'   * \emph{multivariate case}: a list with elements \code{def}, containing the
+#'   name of the depth notion to be used to compute depths (\code{BD} or
+#'   \code{MBD}), and \code{weights}, containing the value of parameter
+#'   \code{weights} to be passed to the depth function. Default is
+#'   \code{list(def = 'MBD', weights = 'uniform')}.
+#'
 #' In both cases the name of the functions to compute depths must be available
 #' in the caller's environment.
-#' @param Fvalue the value of the inflation factor \eqn{F}, default is
-#' \code{F = 1.5}.
+#' @param Fvalue the value of the inflation factor \eqn{F}, default is \code{F =
+#'   1.5}.
 #' @param adjust either \code{FALSE} if you would like the default value for the
-#' inflation factor, \eqn{F = 1.5}, to be used, or (for now \bold{only in the
-#' univariate functional case}) a list specifying the parameters required by
-#' the adjustment:
-#'  \itemize{
-#'  \item{"\code{N_trials}"}{: the number of repetitions of the adujustment
-#'  procedure based on the simulation of a gaussisan population of functional
-#'  data, each one producing an adjusted value of \eqn{F}, which will lead
-#'  to the averaged adjusted value \eqn{\bar{F}}. Default is 20;}
-#'  \item{"\code{trial_size}"}{: the number of elements in the gaussian
-#'  population of functional data that will be simulated at each repetition of
-#'  the adjustment procedure. Default is 8 * \code{Data$N};}
-#'  \item{"\code{TPR}"}{: the True Positive Rate of outliers, i.e. the proportion
-#'  of observations in a dataset without amplitude outliers that have to be
-#'  considered outliers. Default is \code{2 * pnorm( 4 * qnorm( 0.25 ) )};}
-#'  \item{"\code{F_min}"}{: the minimum value of \eqn{F}, defining the left
-#'  boundary for the optimisation problem aimed at finding, for a given dataset
-#'  of simulated gaussian data associated to \code{Data}, the optimal value of
-#'  \eqn{F}. Default is 0.5;}
-#'  \item{"\code{F_max}"}{: the maximum value of \eqn{F}, defining the right
-#'  boundary for the optimisation problem aimed at finding, for a given dataset
-#'  of simulated gaussian data associated to \code{Data}, the optimal value of
-#'  \eqn{F}. Default is 5;}
-#'  \item{"\code{tol}"}{: the tolerance to be used in the optimisation problem
-#'  aimed at finding, for a given dataset of simulated gaussian data associated
-#'  to \code{Data}, the optimal value of \eqn{F}. Default is \code{1e-3};}
-#'  \item{"\code{maxiter}"}{: the maximum number of iterations to solve the
-#'  optimisation problem aimed at finding, for a given dataset of simulated
-#'  gaussian data associated to \code{Data}, the optimal value of \eqn{F}.
-#'  Default is \code{100};}
-#'  \item{"\code{VERBOSE}"}{: a parameter controlling the verbosity of the
-#'  adjustment process;}
-#'  }
-#' @param display either a logical value indicating wether you want the
-#' outliergram to be displayed, or the number of the graphical device
-#' where you want the outliergram to be displayed.
+#'   inflation factor, \eqn{F = 1.5}, to be used, or (for now \bold{only in the
+#'   univariate functional case}) a list specifying the parameters required by
+#'   the adjustment:
+#'
+#'   * \code{N_trials}: the number of repetitions of the adjustment procedure
+#'   based on the simulation of a gaussian population of functional data, each
+#'   one producing an adjusted value of \eqn{F}, which will lead to the averaged
+#'   adjusted value \eqn{\bar{F}}. Default is 20.
+#'   * \code{trial_size}: the number of elements in the gaussian population of
+#'   functional data that will be simulated at each repetition of the adjustment
+#'   procedure. Default is 8 * \code{Data$N}.
+#'   * \code{TPR}: the True Positive Rate of outliers, i.e. the proportion of
+#'   observations in a dataset without amplitude outliers that have to be
+#'   considered outliers. Default is \code{2 * pnorm(4 * qnorm(0.25))}.
+#'   * \code{F_min}: the minimum value of \eqn{F}, defining the left boundary
+#'   for the optimization problem aimed at finding, for a given dataset of
+#'   simulated gaussian data associated to \code{Data}, the optimal value of
+#'   \eqn{F}. Default is 0.5.
+#'   * \code{F_max}: the maximum value of \eqn{F}, defining the right boundary
+#'   for the optimization problem aimed at finding, for a given dataset of
+#'   simulated gaussian data associated to \code{Data}, the optimal value of
+#'   \eqn{F}. Default is 5.
+#'   * \code{tol}: the tolerance to be used in the optimization problem aimed at
+#'   finding, for a given dataset of simulated gaussian data associated to
+#'   \code{Data}, the optimal value of \eqn{F}. Default is \code{1e-3}.
+#'   * \code{maxiter}: the maximum number of iterations to solve the
+#'   optimization problem aimed at finding, for a given dataset of simulated
+#'   gaussian data associated to \code{Data}, the optimal value of \eqn{F}.
+#'   Default is \code{100}.
+#'   * \code{VERBOSE}: a parameter controlling the verbosity of the adjustment
+#'   process.
+#'
+#' @param display either a logical value indicating whether you want the
+#'   functional boxplot to be displayed, or the number of the graphical device
+#'   where you want the functional boxplot to be displayed.
 #' @param xlab the label to use on the x axis when displaying the functional
-#' boxplot.
-#' @param ylab the label (or list of labels for the multivariate functional case)
-#' to use on the y axis when displaying the functional boxplot.
+#'   boxplot.
+#' @param ylab the label (or list of labels for the multivariate functional
+#'   case) to use on the y axis when displaying the functional boxplot.
 #' @param main the main title (or list of titles for the multivariate functional
-#' case) to be used when displaying the functional boxplot.
+#'   case) to be used when displaying the functional boxplot.
 #' @param ... additional graphical parameters to be used in plotting functions.
 #'
-#' @return
-#' Even when used in graphical way to plot the functional boxplot, the function
-#' returns a list of three elements: the first, \code{Depths}, contains the depths
-#' of each element of the functional dataset; the second, \code{Fvalue}, is the
-#' value of F used to obtain the outliers, and the third, \code{ID_out}, contains
-#' the vector of indices of dataset's elements flagged as outliers (if any).
+#' @return Even when used in graphical way to plot the functional boxplot, the
+#'   function returns a list of three elements:
+#'
+#'   * \code{Depths}: contains the depths of each element of the functional
+#'   dataset.
+#'   * \code{Fvalue}: is the value of F used to obtain the outliers.
+#'   * \code{ID_out}: contains the vector of indices of dataset elements flagged
+#'   as outliers (if any).
 #'
 #' @references
 #'
-#'
-#'	Sun, Y., & Genton, M. G. (2012). Functional boxplots. Journal of
-#'	Computational and Graphical Statistics.
-#'
-#'	Sun, Y., & Genton, M. G. (2012). Adjusted functional boxplots for spatio-
-#'	temporal data visualization and outlier detection. Environmetrics, 23(1), 54-64.
+#'   1. Sun, Y., & Genton, M. G. (2012). Functional boxplots. Journal of
+#'   Computational and Graphical Statistics.
+#'   1. Sun, Y., & Genton, M. G. (2012). Adjusted functional boxplots for
+#'   spatio-temporal data visualization and outlier detection. Environmetrics,
+#'   23(1), 54-64.
 #'
 #' @examples
 #'
@@ -119,7 +119,9 @@
 #' fD = fData( grid, D )
 #'
 #' dev.new()
-#' par( mfrow = c(1,3) )
+#' oldpar <- par(mfrow = c(1, 1))
+#' par(mfrow = c(1, 3))
+#'
 #' plot( fD, lwd = 2, main = 'Functional dataset',
 #'       xlab = 'time', ylab = 'values' )
 #'
@@ -127,6 +129,8 @@
 #'
 #' boxplot(fD$values[,1], ylim = range(fD$values), main = 'Boxplot of functional dataset at t_0 ' )
 #'
+#' par(oldpar)
+#'
 #' # UNIVARIATE FUNCTIONAL BOXPLOT - WITH ADJUSTMENT
 #'
 #'
@@ -145,7 +149,7 @@
 #' fD = fData( grid, Data )
 #'
 #' dev.new()
-#' \dontrun{
+#' \donttest{
 #' fbplot( fD, adjust = list( N_trials = 10,
 #'                            trial_size = 5 * N,
 #'                            VERBOSE = TRUE ),
@@ -188,7 +192,6 @@
 #' \code{\link{mfData}}, \code{\link{multiMBD}}, \code{\link{multiBD}}
 #'
 #' @export
-#'
 fbplot = function( Data,
                    Depths = 'MBD',
                    Fvalue = 1.5,
@@ -221,7 +224,7 @@ fbplot.fData = function( Data,
   # Checking if depths have already been provided or must be computed
   if( is.character( Depths ) )
   {
-    # Nice trick to encapsulate the information on the desired definiton of
+    # Nice trick to encapsulate the information on the desired definition of
     # depth inside the vector that supposedly should contain depth values
     Depths_spec = Depths
 
@@ -316,7 +319,7 @@ fbplot.fData = function( Data,
 
       if( VERBOSE > 0 )
       {
-        cat( ' * * * * beginning optimisation\n' )
+        cat( ' * * * * beginning optimization\n' )
       }
 
       opt = uniroot( cost_functional,
@@ -325,7 +328,7 @@ fbplot.fData = function( Data,
                      maxiter = maxiter )
       if( VERBOSE > 0 )
       {
-        cat( ' * * * * optimisation finished.\n')
+        cat( ' * * * * optimization finished.\n')
       }
 
       Fvalues[ iTrial ] = opt$root
@@ -567,7 +570,9 @@ provided in the multivariate version of the functional boxplot' )
     mfrow_rows = ceiling( Data$L / 2 )
     mfrow_cols = 2
 
-    par( mfrow = c( mfrow_rows, mfrow_cols ) )
+    oldpar <- par(mfrow = c(1, 1))
+    on.exit(par(oldpar))
+    par(mfrow = c(mfrow_rows, mfrow_cols))
 
     # Creating color palettes
     col_non_outlying = scales::hue_pal( h = c( 180, 270 ),
@@ -724,7 +729,7 @@ provided in the multivariate version of the functional boxplot' )
   fence_upper = ( max_envelope_central - min_envelope_central ) * Fvalue + max_envelope_central
   fence_lower = ( min_envelope_central - max_envelope_central ) * Fvalue + min_envelope_central
 
-  ID_outlying = unique( unlist( sapply( 1 : L, function( iL ) ( which(
+  ID_outlying = unique( unlist( lapply( 1 : L, function( iL ) ( which(
     apply( listOfValues[[ iL ]], 1,
            function( x ) ( any( x > as.numeric( fence_upper[ iL, ] ) ) |
                              any( x < as.numeric( fence_lower[ iL, ] ) ) ) ) )
