@@ -6,15 +6,15 @@
 #'
 #' @section Adjustment:
 #'
-#' When the adjustment option is selected, the value of \eqn{F} is optimised for
+#' When the adjustment option is selected, the value of \eqn{F} is optimized for
 #' the univariate functional dataset provided with \code{fData}. In practice,
 #' a number \code{adjust$N_trials} of times a synthetic population
 #' (of size \code{adjust$trial_size} with the same covariance (robustly
 #' estimated from data) and centerline as \code{fData} is simulated without
-#' outliers and each time an optimised value \eqn{F_i} is computed so that a
+#' outliers and each time an optimized value \eqn{F_i} is computed so that a
 #' given proportion (\code{adjust$TPR}) of observations is flagged as outliers.
 #' The final value of \code{F} for the outliergram is determined as an average
-#' of \eqn{F_1, F_2, \ldots, F_{N_{trials}}}. At each time step the optimisation
+#' of \eqn{F_1, F_2, \ldots, F_{N_{trials}}}. At each time step the optimization
 #' problem is solved using \code{stats::uniroot} (Brent's method).
 #'
 #' @param fData the univariate functional dataset whose outliergram has to be
@@ -35,35 +35,35 @@
 #' inflation factor, \eqn{F = 1.5}, to be used, or a list specifying the
 #' parameters required by the adjustment.
 #'  \itemize{
-#'  \item{"\code{N_trials}"}{: the number of repetitions of the adujustment
-#'  procedure based on the simulation of a gaussisan population of functional
+#'  \item{"\code{N_trials}"}{: the number of repetitions of the adjustment
+#'  procedure based on the simulation of a gaussian population of functional
 #'  data, each one producing an adjusted value of \eqn{F}, which will lead
 #'  to the averaged adjusted value \eqn{\bar{F}}. Default is 20;}
 #'  \item{"\code{trial_size}"}{: the number of elements in the gaussian
 #'  population of functional data that will be simulated at each repetition of
 #'  the adjustment procedure. Default is \code{5 * fData$N};}
-#'  \item{"\code{TPR}"}{: the True Positive Rate of outleirs, i.e. the proportion
+#'  \item{"\code{TPR}"}{: the True Positive Rate of outliers, i.e. the proportion
 #'  of observations in a dataset without shape outliers that have to be considered
 #'  outliers. Default is \code{2 * pnorm( 4 * qnorm( 0.25 ) )};}
 #'  \item{"\code{F_min}"}{: the minimum value of \eqn{F}, defining the left
-#'  boundary for the optimisation problem aimed at finding, for a given dataset
+#'  boundary for the optimization problem aimed at finding, for a given dataset
 #'  of simulated gaussian data associated to \code{fData}, the optimal value of
 #'  \eqn{F}. Default is 0.5;}
 #'  \item{"\code{F_max}"}{: the maximum value of \eqn{F}, defining the right
-#'  boundary for the optimisation problem aimed at finding, for a given dataset
+#'  boundary for the optimization problem aimed at finding, for a given dataset
 #'  of simulated gaussian data associated to \code{fData}, the optimal value of
 #'  \eqn{F}. Default is 20;}
-#'  \item{"\code{tol}"}{: the tolerance to be used in the optimisation problem
+#'  \item{"\code{tol}"}{: the tolerance to be used in the optimization problem
 #'  aimed at finding, for a given dataset of simulated gaussian data associated
 #'  to \code{fData}, the optimal value of \eqn{F}. Default is \code{1e-3};}
 #'  \item{"\code{maxiter}"}{: the maximum number of iterations to solve the
-#'  optimisation problem aimed at finding, for a given dataset of simulated
+#'  optimization problem aimed at finding, for a given dataset of simulated
 #'  gaussian data associated to \code{fData}, the optimal value of \eqn{F}.
 #'  Default is \code{100};}
 #'  \item{"\code{VERBOSE}"}{: a parameter controlling the verbosity of the
 #'  adjustment process;}
 #'  }
-#' @param display either a logical value indicating wether you want the
+#' @param display either a logical value indicating whether you want the
 #' outliergram to be displayed, or the number of the graphical device
 #' where you want the outliergram to be displayed.
 #' @param xlab a list of two labels to use on the x axis when displaying the
@@ -94,53 +94,70 @@
 #' \code{\link{fbplot}}
 #'
 #' @examples
+#' set.seed(1618)
 #'
+#' N <- 200
+#' P <- 200
+#' N_extra <- 4
 #'
-#' set.seed( 1618 )
+#' grid <- seq(0, 1, length.out = P)
 #'
-#' N = 200
-#' P = 200
-#' N_extra = 4
+#' Cov <- exp_cov_function(grid, alpha = 0.2, beta = 0.8)
 #'
-#' grid = seq( 0, 1, length.out = P )
+#' Data <- generate_gauss_fdata(
+#'   N = N,
+#'   centerline = sin(4 * pi * grid),
+#'   Cov = Cov
+#' )
 #'
-#' Cov = exp_cov_function( grid, alpha = 0.2, beta = 0.8 )
+#' Data_extra <- array(0, dim = c(N_extra, P))
 #'
-#' Data = generate_gauss_fdata( N,
-#'                              centerline = sin( 4 * pi * grid ),
-#'                              Cov = Cov )
+#' Data_extra[1, ] <- generate_gauss_fdata(
+#'   N = 1,
+#'   centerline = sin(4 * pi * grid + pi / 2),
+#'   Cov = Cov
+#' )
 #'
-#' Data_extra = array( 0, dim = c( N_extra, P ) )
+#' Data_extra[2, ] <- generate_gauss_fdata(
+#'   N = 1,
+#'   centerline = sin(4 * pi * grid - pi / 2),
+#'   Cov = Cov
+#' )
 #'
-#' Data_extra[ 1, ] = generate_gauss_fdata( 1,
-#'                                          sin( 4 * pi * grid + pi / 2 ),
-#'                                          Cov = Cov )
+#' Data_extra[3, ] <- generate_gauss_fdata(
+#'   N = 1,
+#'   centerline = sin(4 * pi * grid + pi / 3),
+#'   Cov = Cov
+#' )
 #'
-#' Data_extra[ 2, ] = generate_gauss_fdata( 1,
-#'                                          sin( 4 * pi * grid - pi / 2 ),
-#'                                          Cov = Cov )
+#' Data_extra[4, ] <- generate_gauss_fdata(
+#'   N = 1,
+#'   centerline = sin(4 * pi * grid - pi / 3),
+#'   Cov = Cov
+#' )
 #'
-#' Data_extra[ 3, ] = generate_gauss_fdata( 1,
-#'                                          sin( 4 * pi * grid + pi/ 3 ),
-#'                                          Cov = Cov )
+#' Data <- rbind(Data, Data_extra)
 #'
-#' Data_extra[ 4, ] = generate_gauss_fdata( 1,
-#'                                          sin( 4 * pi * grid - pi / 3),
-#'                                          Cov = Cov )
-#' Data = rbind( Data, Data_extra )
+#' fD <- fData(grid, Data)
 #'
-#' fD = fData( grid, Data )
+#' # Outliergram with default Fvalue = 1.5
+#' outliergram(fD, display = TRUE)
 #'
-#' outliergram( fD, display = TRUE )
+#' # Outliergram with Fvalue enforced to 2.5
+#' outliergram(fD, Fvalue = 2.5, display = TRUE)
 #'
-#' outliergram( fD, Fvalue = 2.5, display = TRUE )
-#' \dontrun{
-#' outliergram( fD,
-#'              adjust = list( N_trials = 10,
-#'                             trial_size = 5 * nrow( Data ),
-#'                             TPR = 0.01,
-#'                             VERBOSE = FALSE ),
-#'              display = TRUE )
+#' \donttest{
+#' # Outliergram with estimated Fvalue to ensure TPR of 1%
+#' outliergram(
+#'   fData = fD,
+#'   adjust = list(
+#'     N_trials = 10,
+#'     trial_size = 5 * nrow(Data),
+#'     TPR = 0.01,
+#'     VERBOSE = FALSE
+#'   ),
+#'   display = TRUE
+#' )
 #' }
 #'
 #' @importFrom grDevices dev.set dev.cur
@@ -250,7 +267,7 @@ outliergram = function( fData, MBD_data = NULL, MEI_data = NULL, p_check = 0.05,
 
       if( VERBOSE > 0 )
       {
-        cat( ' * * * * beginning optimisation\n' )
+        cat( ' * * * * beginning optimization\n' )
       }
 
       opt = uniroot( obj_function,
@@ -308,7 +325,9 @@ outliergram = function( fData, MBD_data = NULL, MEI_data = NULL, p_check = 0.05,
     }
 
     dev.cur()
-    par( mfrow = c( 1, 2 ) )
+    oldpar <- par(mfrow = c(1, 1))
+    on.exit(par(oldpar))
+    par(mfrow = c(1, 2))
 
     # Plotting functional data
     if( length( out$ID_SO ) > 0 )
@@ -512,7 +531,7 @@ outliergram = function( fData, MBD_data = NULL, MEI_data = NULL, p_check = 0.05,
 #' Default is \code{1.5};
 #' @param shift whether to apply the shifting algorithm to properly manage observations having low
 #' or high MEI. Default is TRUE.
-#' @param display either a logical value indicating wether you want the
+#' @param display either a logical value indicating whether you want the
 #' outliergram to be displayed, or the number of the graphical device
 #' where you want the outliergram to be displayed;
 #' @param xlab the label to use on the x axis in the outliergram plot;
